==> jc-1.4.0.tar.gz: soot/jimple/spark/builder/ContextInsensitiveBuilder.h <==
// public class soot.jimple.spark.builder.ContextInsensitiveBuilder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e09b831b4a4258c5 soot_jimple_spark_builder_ContextInsensitiveBuilder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_builder_ContextInsensitiveBuilder_H_
#define _JC_soot_jimple_spark_builder_ContextInsensitiveBuilder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;
struct _jc_soot_jimple_spark_solver_OnFlyCallGraph$object;
struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object;
struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object;
struct _jc_soot_options_AbstractSparkOptions$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$sub_refs	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$sub_refs;
typedef struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$sub_nonrefs	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$refs	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$refs;
typedef struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$nonrefs	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$nonrefs;
typedef struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object;

typedef const struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vmethods	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vmethods;
typedef const struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vtable	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vtable;
typedef const struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vtype	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vtype;

// Constructors
extern void _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object *);

// Virtual methods
extern void _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$method$build$8dbf5d5babe4b103(_jc_env *, struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object *);
extern void _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$method$handleClass$bf8747bfb77edb12(_jc_env *, struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object *, struct _jc_soot_SootClass$object *);
extern void _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$method$preJimplify$b3df2e7332aa1591(_jc_env *, struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object *);
extern struct _jc_soot_jimple_spark_pag_AbstractPAG$object *_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$method$setup$1f4bda53a11bc9b4(_jc_env *, struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object *, struct _jc_soot_options_AbstractSparkOptions$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$method_info$build$8dbf5d5babe4b103;
extern _jc_method _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$method_info$handleClass$bf8747bfb77edb12;
extern _jc_method _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$method_info$preJimplify$b3df2e7332aa1591;
extern _jc_method _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$method_info$setup$1f4bda53a11bc9b4;

// Virtual methods structure
struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vmethods {
	void	(*build$8dbf5d5babe4b103)(_jc_env *, struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object *);
	void	(*handleClass$bf8747bfb77edb12)(_jc_env *, struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object *, struct _jc_soot_SootClass$object *);
	void	(*preJimplify$b3df2e7332aa1591)(_jc_env *, struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object *);
	struct _jc_soot_jimple_spark_pag_AbstractPAG$object	*(*setup$1f4bda53a11bc9b4)(_jc_env *, struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object *, struct _jc_soot_options_AbstractSparkOptions$object *);
};

// Vtable
struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vmethods	soot_jimple_spark_builder_ContextInsensitiveBuilder;
};

// Vtype
struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$sub_refs {
	struct _jc_soot_jimple_spark_pag_AbstractPAG$object	*pag;
	struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object	*cgb;
	struct _jc_soot_jimple_spark_solver_OnFlyCallGraph$object	*ofcg;
	struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object	*reachables;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$refs {
    _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$sub_refs	soot_jimple_spark_builder_ContextInsensitiveBuilder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$sub_nonrefs {
	jint	classes;
	jint	totalMethods;
	jint	analyzedMethods;
	jint	stmts;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$sub_nonrefs	soot_jimple_spark_builder_ContextInsensitiveBuilder;
};

// Object instance structure
struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object {
	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vtype	*vtype;
	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vtype _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_builder_ContextInsensitiveBuilder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$class_object;

#endif	/* _JC_soot_jimple_spark_builder_ContextInsensitiveBuilder_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/builder/ContextInsensitiveBuilder.h <==
// public class soot.jimple.spark.builder.ContextInsensitiveBuilder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e09b831b4a4258c5 soot_jimple_spark_builder_ContextInsensitiveBuilder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_builder_ContextInsensitiveBuilder_H_
#define _JC_soot_jimple_spark_builder_ContextInsensitiveBuilder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;
struct _jc_soot_jimple_spark_solver_OnFlyCallGraph$object;
struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object;
struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object;
struct _jc_soot_options_AbstractSparkOptions$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$sub_refs	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$sub_refs;
typedef struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$sub_nonrefs	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$refs	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$refs;
typedef struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$nonrefs	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$nonrefs;
typedef struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object;

typedef const struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vmethods	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vmethods;
typedef const struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vtable	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vtable;
typedef const struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vtype	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vtype;

// Constructors
extern void _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$method$build$8dbf5d5babe4b103(_jc_env *, struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$method$handleClass$bf8747bfb77edb12(_jc_env *, struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$method$preJimplify$b3df2e7332aa1591(_jc_env *, struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_spark_pag_AbstractPAG$object *_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$method$setup$1f4bda53a11bc9b4(_jc_env *, struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object *, struct _jc_soot_options_AbstractSparkOptions$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$method_info$build$8dbf5d5babe4b103;
extern _jc_method _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$method_info$handleClass$bf8747bfb77edb12;
extern _jc_method _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$method_info$preJimplify$b3df2e7332aa1591;
extern _jc_method _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$method_info$setup$1f4bda53a11bc9b4;

// Virtual methods structure
struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vmethods {
	void	(*build$8dbf5d5babe4b103)(_jc_env *, struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object *) _JC_JCNI_ATTR;
	void	(*handleClass$bf8747bfb77edb12)(_jc_env *, struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;
	void	(*preJimplify$b3df2e7332aa1591)(_jc_env *, struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_spark_pag_AbstractPAG$object	*(*setup$1f4bda53a11bc9b4)(_jc_env *, struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object *, struct _jc_soot_options_AbstractSparkOptions$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vmethods	soot_jimple_spark_builder_ContextInsensitiveBuilder;
};

// Vtype
struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$sub_refs {
	struct _jc_soot_jimple_spark_pag_AbstractPAG$object	*pag;
	struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object	*cgb;
	struct _jc_soot_jimple_spark_solver_OnFlyCallGraph$object	*ofcg;
	struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object	*reachables;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$refs {
    _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$sub_refs	soot_jimple_spark_builder_ContextInsensitiveBuilder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$sub_nonrefs {
	jint	classes;
	jint	totalMethods;
	jint	analyzedMethods;
	jint	stmts;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$sub_nonrefs	soot_jimple_spark_builder_ContextInsensitiveBuilder;
};

// Object instance structure
struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object {
	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vtype	*vtype;
	_jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$vtype _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_builder_ContextInsensitiveBuilder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$class_object;

#endif	/* _JC_soot_jimple_spark_builder_ContextInsensitiveBuilder_H_ */
